@@ -85,17 +85,17 @@ class AnsiblePlaybooks:
         if driver_dict:
             try:
                 playbook = driver_dict[section]
-            except Exception:
-                pass
+            except Exception as exc:
+                LOG.exception(exc)
         if playbook is not None:
             playbook = self._config.provisioner.abs_path(playbook)
             playbook = self._normalize_playbook(playbook)
 
             if os.path.exists(playbook):
                 return playbook
-            elif os.path.exists(self._get_bundled_driver_playbook(section)):
+            if os.path.exists(self._get_bundled_driver_playbook(section)):
                 return self._get_bundled_driver_playbook(section)
-            elif section not in [
+            if section not in [
                 # these playbooks can be considered optional
                 "prepare",
                 "create",
@@ -105,6 +105,7 @@ class AnsiblePlaybooks:
                 "verify",
             ]:
                 return playbook
+        return None
 
     def _get_bundled_driver_playbook(self, section):
         path = self._config.driver.get_playbook(section)
@@ -130,7 +131,6 @@ class AnsiblePlaybooks:
 
         Currently used to deprecate use of playbook.yml in favour of converge.yml
         """
-        # TODO(ssbarnea): Remove that deprecation fallback in 3.1+
         if not playbook or os.path.isfile(playbook):
             return playbook
 
